@@ -35,10 +35,10 @@ class OxCGRTData(CleaningBase):
     def __init__(self, filename):
         super().__init__(filename)
 
-    def cleaning(self):
+    def _cleaning(self):
         """
         Perform data cleaning of the raw data.
-        This method overwrite super().cleaning() method.
+        This method overwrite super()._cleaning() method.
         Policy indices (Overall etc.) are from
         README.md and documentation/index_methodology.md in
         https://github.com/OxCGRT/covid-policy-tracker/
@@ -64,7 +64,7 @@ class OxCGRTData(CleaningBase):
             axis=1
         )
         # Confirm the expected columns are in raw data
-        self.validate_dataframe(
+        self.ensure_dataframe(
             df, name="the raw data", columns=self.OXCGRT_COLS
         )
         # Read date records
@@ -81,12 +81,6 @@ class OxCGRTData(CleaningBase):
         df = df.loc[:, [self.DATE, self.COUNTRY, self.ISO3, *float_cols]]
         return df
 
-    def total(self):
-        """
-        Cannot be used.
-        """
-        raise AttributeError("This method is not defined.")
-
     def subset(self, country=None, iso3=None):
         """
         Create a subset for a country.
@@ -125,3 +119,12 @@ class OxCGRTData(CleaningBase):
         if not df.empty:
             return df
         raise KeyError(f"@country {country} is not included in the dataset.")
+
+    def total(self):
+        """
+        This is not defined for this child class.
+
+        Raises:
+            AttributeError: if called
+        """
+        raise AttributeError("OxCGRTData.total() is not defined.")
