@@ -3,6 +3,7 @@
 
 from collections import defaultdict
 from datetime import datetime
+from methodtools import lru_cache
 import numpy as np
 import pandas as pd
 from covsirphy.util.error import deprecate
@@ -68,6 +69,7 @@ class Term(object):
     # Flag
     UNKNOWN = "-"
 
+    @lru_cache(maxsize=None)
     @classmethod
     def num2str(cls, num):
         """
@@ -97,6 +99,7 @@ class Term(object):
         """
         return a * np.exp(-b * x)
 
+    @lru_cache(maxsize=None)
     @classmethod
     def date_obj(cls, date_str):
         """
@@ -134,12 +137,12 @@ class Term(object):
         return flattened
 
     @staticmethod
-    def validate_dataframe(target, name="df", time_index=False, columns=None):
+    def ensure_dataframe(target, name="df", time_index=False, columns=None):
         """
-        Validate the dataframe has the columns.
+        Ensure the dataframe has the columns.
 
         Args:
-            target (pandas.DataFrame): the dataframe to validate
+            target (pandas.DataFrame): the dataframe to ensure
             name (str): argument name of the dataframe
             time_index (bool): if True, the dataframe must has DatetimeIndex
             columns (list[str] or None): the columns the dataframe must have
@@ -163,14 +166,14 @@ class Term(object):
         return df
 
     @staticmethod
-    def validate_natural_int(target, name="number", include_zero=False):
+    def ensure_natural_int(target, name="number", include_zero=False):
         """
-        Validate a natural (non-negative) number.
+        Ensure a natural (non-negative) number.
         If the value is a natural number and the type was float or string,
         it will be converted to an integer.
 
         Args:
-            target (int or float or str): value to validate
+            target (int or float or str): value to ensure
             name (str): argument name of the value
             include_zero (bool): include 0 or not
 
@@ -190,14 +193,14 @@ class Term(object):
         return number
 
     @staticmethod
-    def validate_float(target, name="value"):
+    def ensure_float(target, name="value"):
         """
-        Validate a float value.
+        Ensure a float value.
         If the value is a float value and the type was string,
         it will be converted to a float.
 
         Args:
-            target (float or str): value to validate
+            target (float or str): value to ensure
             name (str): argument name of the value
 
         Returns:
@@ -211,12 +214,12 @@ class Term(object):
         return value
 
     @classmethod
-    def validate_date(cls, target, name="date"):
+    def ensure_date(cls, target, name="date"):
         """
-        Validate the format of the string.
+        Ensure the format of the string.
 
         Args:
-            target (str): string to validate
+            target (str): string to ensure
             name (str): argument name of the string
 
         Returns:
@@ -231,12 +234,12 @@ class Term(object):
         return target
 
     @staticmethod
-    def validate_subclass(target, parent, name="target"):
+    def ensure_subclass(target, parent, name="target"):
         """
-        Validate the target is a subclass of the parent class.
+        Ensure the target is a subclass of the parent class.
 
         Args:
-            target (object): target to validate
+            target (object): target to ensure
             parent (object): parent class
             name (str): argument name of the target
 
@@ -249,12 +252,12 @@ class Term(object):
         return target
 
     @staticmethod
-    def validate_instance(target, class_obj, name="target"):
+    def ensure_instance(target, class_obj, name="target"):
         """
-        Validate the target is a instance of the class object.
+        Ensure the target is a instance of the class object.
 
         Args:
-            target (instance): target to validate
+            target (instance): target to ensure
             parent (class): class object
             name (str): argument name of the target
 
@@ -266,6 +269,7 @@ class Term(object):
             raise TypeError(s)
         return target
 
+    @lru_cache(maxsize=None)
     @classmethod
     def divisors(cls, value):
         """
@@ -277,12 +281,13 @@ class Term(object):
         Returns:
             (list[int]): the list of divisors
         """
-        value = cls.validate_natural_int(value)
+        value = cls.ensure_natural_int(value)
         divisors = [
             i for i in range(1, value + 1) if value % i == 0
         ]
         return divisors
 
+    @lru_cache(maxsize=None)
     @classmethod
     def to_date_obj(cls, date_str=None, default=None):
         """
