@@ -46,7 +46,7 @@ class SIRD(ModelBase):
 
     def __init__(self, population, kappa, rho, sigma):
         # Total population
-        self.population = self.validate_natural_int(
+        self.population = self.ensure_natural_int(
             population, name="population"
         )
         # Non-dim parameters
@@ -92,7 +92,7 @@ class SIRD(ModelBase):
                 - key (str): parameter name
                 - value (tuple(float, float)): min value and max value
         """
-        df = cls.validate_dataframe(
+        df = cls.ensure_dataframe(
             taufree_df, name="taufree_df", columns=[cls.TS, *cls.VARIABLES]
         )
         n, t = population, df[cls.TS]
