@@ -49,7 +49,7 @@ class SIRF(ModelBase):
 
     def __init__(self, population, theta, kappa, rho, sigma):
         # Total population
-        self.population = self.validate_natural_int(
+        self.population = self.ensure_natural_int(
             population, name="population"
         )
         # Non-dim parameters
@@ -96,7 +96,7 @@ class SIRF(ModelBase):
                 - key (str): parameter name
                 - value (tuple(float, float)): min value and max value
         """
-        df = cls.validate_dataframe(
+        df = cls.ensure_dataframe(
             taufree_df, name="taufree_df", columns=[cls.TS, *cls.VARIABLES]
         )
         n, t = population, df[cls.TS]
